@@ -19,27 +19,29 @@
 
 /**
  * Biloba - Q1 2005
-	* Game by Guillaume Demougeot <dmgt@wanadoo.fr>
-	* Code by Colin Leroy <colin@colino.net>
-	*
-	* This file only contains the game freer used by options.c
-	* and server.c.
-	*/
+ * Game by Guillaume Demougeot <dmgt@wanadoo.fr>
+ * Code by Colin Leroy <colin@colino.net>
+ *
+ * This file only contains the game freer used by options.c
+ * and server.c.
+ */
 
 #include <stdlib.h>
 #include "game.h"
 
+/**
+ * Free a game struct
+ * @param game		The game to free
+ */
 void game_free(Game *game)
 {
 	int i = 0;
 	if (!game)
 		return;
 
-	if (game->name)
-		free(game->name);
+	free(game->name);
 	for (i = 0; i < 4; i++) {
-		if (game->player_name[i])
-			free(game->player_name[i]);
+		free(game->player_name[i]);
 	}
 	free(game);
 }
