@@ -39,7 +39,7 @@ struct _Game
 	int killed;
 	int last_joined;
 
-#ifndef __MINGW32__
+#if (!defined __MINGW32__ && !defined MAEMO)
 	pthread_cond_t  cond_wait;
 	pthread_cond_t  cond_move;
 	pthread_cond_t  cond_quit;
