@@ -1,6 +1,6 @@
 /*
  * Biloba
- * Copyright (C) 2004-2005 Guillaume Demougeot, Colin Leroy
+ * Copyright (C) 2004-2008 Guillaume Demougeot, Colin Leroy
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,12 +19,12 @@
 
 /**
  * Biloba - Q1 2005
-	* Game by Guillaume Demougeot <dmgt@wanadoo.fr>
-	* Code by Colin Leroy <colin@colino.net>
-	*
-	* This file contains all early game initialisation
-	* and termination.
-	*/
+ * Game by Guillaume Demougeot <dmgt@wanadoo.fr>
+ * Code by Colin Leroy <colin@colino.net>
+ *
+ * This file contains all early game initialisation
+ * and termination.
+ */
 
 #include <stdlib.h>
 #include <string.h>
@@ -61,6 +61,7 @@ int main(int argc, char *argv[])
 		net_set_server(argv[1]);
 	}
 	SDL_Init(SDL_INIT_EVERYTHING|SDL_INIT_NOPARACHUTE);
+	SDL_EnableUNICODE(1);
 	if ( (screen=SDL_SetVideoMode(XS, YS, BPP, FLAGS)) == NULL ) {
 		fprintf(stderr, "Couldn't set %dx%dx%d video mode: %s\n", 
 				XS, YS, BPP, SDL_GetError());
